Index: /trunk/src/VBox/Frontends/VirtualBox/src/globals/UICloudNetworkingStuff.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/globals/UICloudNetworkingStuff.cpp	(revision 86608)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/globals/UICloudNetworkingStuff.cpp	(revision 86609)
@@ -368,4 +368,46 @@
         else
             return comCloudClient.GetCloudMachineList();
+    }
+    /* Return empty list by default: */
+    return QVector<CCloudMachine>();
+}
+
+QVector<CCloudMachine> UICloudNetworkingStuff::listCloudMachineStubs(CCloudClient comCloudClient,
+                                                                     QWidget *pParent /* = 0 */)
+{
+    /* Execute ReadCloudMachineStubList async method: */
+    CProgress comProgress = comCloudClient.ReadCloudMachineStubList();
+    if (!comCloudClient.isOk())
+        msgCenter().cannotAcquireCloudClientParameter(comCloudClient, pParent);
+    else
+    {
+        /* Show "Read cloud machine stubs" progress: */
+        msgCenter().showModalProgressDialog(comProgress,
+                                            QString(),
+                                            ":/progress_reading_appliance_90px.png", pParent, 0);
+        if (!comProgress.isOk() || comProgress.GetResultCode() != 0)
+            msgCenter().cannotAcquireCloudClientParameter(comProgress, pParent);
+        else
+            return comCloudClient.GetCloudMachineStubList();
+    }
+    /* Return empty list by default: */
+    return QVector<CCloudMachine>();
+}
+
+QVector<CCloudMachine> UICloudNetworkingStuff::listCloudMachineStubs(CCloudClient comCloudClient,
+                                                                     QString &strErrorMessage)
+{
+    /* Execute ReadCloudMachineStubList async method: */
+    CProgress comProgress = comCloudClient.ReadCloudMachineStubList();
+    if (!comCloudClient.isOk())
+        strErrorMessage = UIErrorString::formatErrorInfo(comCloudClient);
+    else
+    {
+        /* Show "Read cloud machine stubs" progress: */
+        comProgress.WaitForCompletion(-1);
+        if (!comProgress.isOk() || comProgress.GetResultCode() != 0)
+            strErrorMessage = UIErrorString::formatErrorInfo(comProgress);
+        else
+            return comCloudClient.GetCloudMachineStubList();
     }
     /* Return empty list by default: */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/globals/UICloudNetworkingStuff.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/globals/UICloudNetworkingStuff.h	(revision 86608)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/globals/UICloudNetworkingStuff.h	(revision 86609)
@@ -116,4 +116,10 @@
     SHARED_LIBRARY_STUFF QVector<CCloudMachine> listCloudMachines(CCloudClient comCloudClient,
                                                                   QString &strErrorMessage);
+    /** Acquires cloud machine stubs of certain @a comCloudClient, using @a pParent to show messages according to. */
+    SHARED_LIBRARY_STUFF QVector<CCloudMachine> listCloudMachineStubs(CCloudClient comCloudClient,
+                                                                      QWidget *pParent = 0);
+    /** Acquires cloud machine stubs of certain @a comCloudClient, using @a strErrorMessage to store messages to. */
+    SHARED_LIBRARY_STUFF QVector<CCloudMachine> listCloudMachineStubs(CCloudClient comCloudClient,
+                                                                      QString &strErrorMessage);
 
     /** Acquires @a comCloudMachine ID as a @a uResult, using @a pParent to show messages according to. */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/UITaskCloudListMachines.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/UITaskCloudListMachines.cpp	(revision 86608)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/UITaskCloudListMachines.cpp	(revision 86609)
@@ -24,8 +24,11 @@
 
 
-UITaskCloudListMachines::UITaskCloudListMachines(const QString &strProviderShortName, const QString &strProfileName)
+UITaskCloudListMachines::UITaskCloudListMachines(const QString &strProviderShortName,
+                                                 const QString &strProfileName,
+                                                 bool fWithRefresh)
     : UITask(Type_CloudListMachines)
     , m_strProviderShortName(strProviderShortName)
     , m_strProfileName(strProfileName)
+    , m_fWithRefresh(fWithRefresh)
 {
 }
@@ -52,5 +55,7 @@
     CCloudClient comCloudClient = cloudClientByName(m_strProviderShortName, m_strProfileName, m_strErrorInfo);
     if (m_strErrorInfo.isNull())
-        m_result = listCloudMachines(comCloudClient, m_strErrorInfo);
+        m_result = m_fWithRefresh
+                 ? listCloudMachines(comCloudClient, m_strErrorInfo)
+                 : listCloudMachineStubs(comCloudClient, m_strErrorInfo);
     m_mutex.unlock();
 }
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserAbstractModel.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserAbstractModel.cpp	(revision 86608)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserAbstractModel.cpp	(revision 86609)
@@ -981,5 +981,6 @@
             /* Create list cloud machines task: */
             UITaskCloudListMachines *pTask = new UITaskCloudListMachines(strProviderShortName,
-                                                                         strProfileName);
+                                                                         strProfileName,
+                                                                         true /* with refresh? */);
             if (pTask)
                 uiCommon().threadPoolCloud()->enqueueTask(pTask);
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserModel.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserModel.cpp	(revision 86608)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserModel.cpp	(revision 86609)
@@ -923,5 +923,6 @@
                 AssertPtrReturnVoid(pParentOfParent);
                 UITaskCloudListMachines *pTask = new UITaskCloudListMachines(pParentOfParent->name(),
-                                                                             pParent->name());
+                                                                             pParent->name(),
+                                                                             true /* with refresh? */);
                 AssertPtrReturnVoid(pTask);
                 uiCommon().threadPoolCloud()->enqueueTask(pTask);

Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/UITaskCloudListMachines.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/UITaskCloudListMachines.h	(revision 86608)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/UITaskCloudListMachines.h	(revision 86609)
@@ -41,6 +41,9 @@
     /** Constructs task taking @a strProviderShortName and @a strProfileName as data.
       * @param  strProviderShortName  Brings the provider short name.
-      * @param  strProfileName        Brings the profile name. */
-    UITaskCloudListMachines(const QString &strProviderShortName, const QString &strProfileName);
+      * @param  strProfileName        Brings the profile name.
+      * @param  fWithRefresh          Brings whether the task includes refresh. */
+    UITaskCloudListMachines(const QString &strProviderShortName,
+                            const QString &strProfileName,
+                            bool fWithRefresh);
 
     /** Returns provider short name. */
@@ -48,4 +51,6 @@
     /** Returns profile name. */
     QString profileName() const { return m_strProfileName; }
+    /** Returns whether the task includes refresh. */
+    bool withRefresh() const { return m_fWithRefresh; }
 
     /** Returns error info. */
@@ -69,4 +74,6 @@
     /** Holds the profile name. */
     const QString  m_strProfileName;
+    /** Holds whether the task includes refresh. */
+    const bool     m_fWithRefresh;
 
     /** Holds the error info. */